\name{hdpmPredictSetup}
\alias{hdpmPredictSetup}
\title{Set up posterior predictive inference}
\description{
  Carries out postprocessing of the MCMC output to allow
  posterior predictive inference for patients with
  different covariates in different studies.
}
\usage{
hdpmPredictSetup(
    j = 1, r = 0,
    n = 100, 
    sig = 1,
    nx = 22, xgrid = NULL,
    npa = NULL, p = NULL, px = NULL, X = NULL,
    work.dir = NULL, header = T)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{j}{study}
  \item{r}{indicator for including (0) or not (1) the
    common measure.}
  \item{n}{Number of imputed posterior simulations to use.}
  \item{sig}{Residual standard deviation.}
  \item{nx}{Size of the grid over the time axis to use.}
  \item{xgrid}{Pair with lower and upper end of the grid.}
  \item{p}{number of columns for \code{X}, i.e.,
    dimension of the random effects vector including the
    covariates.}
  \item{px}{Dimension of covariate vector.
    The last \code{px} columns of \code{X} are assumed to
    be the covariates. The first \code{p-px} columns are
    assumed to be random effects.}
  \item{npa}{Number of rows in \code{X}, i.e., number
    of patients for posterior predictive inference.}
  \item{X}{Random effects (dummy values) and covariates
    for future patients, (\code{n} by \code{p}) matrix.
    \code{X} can be a matrix of a file name.}
  \item{work.dir}{directory to save working files.}
  \item{header}{indicator for a header line in \code{X}}
}
\details{
  Must run \code{\link{hdpm}} first to carry out MCMC posterior
  simulation. 
  
  For \code{npa} assumed future patients with given covariates the
  function computes posterior predictive inference of future
  responses. Posterior predictive inference is (naturally) conditional
  on the fixed covariate values \emph{and} conditional on
  the first random effect. This is meaningful if the first
  random effect is interpretable as a baseline. It makes posterior
  predictive inference comparable across covariates.
  If no conditioning is desired, make the first random effect
  a dummy.

  The \code{npa} by \code{p} matix \code{X} specifies the covariates
  for the future patients. 
  The subvector of random effects in \code{X} is a dummy to match the
  dimension.

  See \code{\link{hpdm-package}} for a statement of the probability
  model.
}
\value{
  No values are returned. All posterior predictive simulations
  are saved in working files in the directory
  \code{work.dir}.
}
\references
{
   Mueller, P., Quintana, F. and Rosner, G. (2004).
  ``Hierarchical Meta-Analysis over Related Non-parametric Bayesian
  Models.''
  Journal of the Royal Statistical Society, Series B, 66, 735--749.}
\author{Peter Mueller}
\note{
  The only functions in the source code that are specific
  to the application in Mueller et al. (2004) are the definition of the
  top level sampling model in the file \code{lpost.c}
  and the functions for resampling (transition probabilities in the
  MCMC) for the random effects in the source file \code{hdpm.c}. Both
  source files are in the directory \code{src} of the package
  distribution. Users with experience in coding MCMC could appropriately
  change these functions and recompile the package for a different
  longitudinal mean function.
}
\seealso{
  The functions in this package implement the application in
  \cite{Mueller et al. (2004).}
  Alternatively, the package
  \code{\link[hdpmn:hdpmn-package]{hdpmn}}
  implements the same hierarchical mixture of Dirichlet process models
  for a multivariate normal sampling model and is useful for
  a wider class of applications.
}
\examples{
\dontrun{
require(hdpm)

## data files
data.dir <- system.file("data",package="hdpm")
work.dir <- paste(getwd(),"/tmp/",sep="")
                  
## data files
Y <- file.path(data.dir,"CALGB.txt")
     ## data: responses
Z <- file.path(data.dir,"CALGBz.txt")  
     ## random effects (initial values) and covariates
X <- file.path(data.dir,"CALGBz0.txt")
     ## same as Z, for future patients (for prediction)

## run MCMC -- save working files in work.dir
hdpm(Y=Y,Z=Z,px=3,q=15,cc=15,work.dir=work.dir)

## post-process MCMC output for predictive inference
## save posterior predictive summaries in work.dir
hdpmPredictSetup(X=X,px=3,
                  j=c(0,1,2,1,2),r=c(0,0,0,1,1),
                  xgrid=c(0,21),work.dir=work.dir)

## plot predictive for future patients in study 1 and 2,
for(i in c(5,7)){
  hdpmPredict(j=1,r=0,i=i)
  hdpmPredict(j=2,r=0,i=i)
}

## part of the predictive corresponding to the idiosyncratic measure
for(i in c(5,7)){
  hdpmPredict(j=1,r=1,i=i, work.dir=work.dir)
  hdpmPredict(j=2,r=1,i=i, work.dir=work.dir)
}

## post-process MCMC output for fitted mean curves
fits <- hdpmFitSetup(px=3,xgrid=c(0,21))

## plot fitted mean curves 
par(mfrow=c(2,2),ask=T)
y <- as.matrix(read.table(Y,header=T)) # read in data
exs <- c(10:17,20:27,30:37,90:97)
for(i in exs){
  hdpmFit(fits,i=i)
  idx <- which(y[,1]==i-1)
  points(y[idx,2],y[idx,3],pch=19)
}

}
}

